==> SyL-0.10.0.tar.gz: SyL/include/framework/SyL_View.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_View.php,v 1.18 2007/04/14 09:59:36 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ̹ǥ饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_View.php,v 1.18 2007/04/14 09:59:36 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_View
{
    /**
     * 쥤ե̾
     * 
     * @access private
     * @param string
     */
    var $layout_file_name = 'layouts.xml';
    /**
     * ե
     * 
     * @access private
     * @var array
     */
    var $config = array();
    /**
     * ƥĥ
     * 
     * @access protected
     * @var string
     */
    var $content_type = '';
    /**
     * ƥ̽Ƚ
     * 
     * @access protected
     * @var bool
     */
    var $content_length = true;
    /**
     * gzipȽ
     * 
     * @access protected
     * @var bool
     */
    var $gzip_compress = true;
    /**
     * ɽƤΥǡ
     * 
     * @access protected
     * @var string
     */
    var $render = '';
    /**
     * ǡ֥
     * 
     * @access protected
     * @var object
     */
    var $dm = null;

    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param object ǡ֥
     */
    function SyL_View(&$dm)
    {
        $this->dm =& $dm;
    }

    /**
     * ƥץ졼ȥ֥Ȥ
     * 
     * @access public
     * @param object ǡ֥
     * @param object ݡͥȥ᥽åɥ֥
     * @return object ӥ塼֥
     */
    function &getObject(&$dm)
    {
        $view = null;
        $type = $dm->getViewParameter('viewtype');

        switch (SYL_ENV_TYPE) {
        case 'web':
            if ($dm->getViewParameter('viewlayout') === 'true') {
                switch ($type) {
                case 'smarty' :
                case 'default':
                    $classname = 'SyL_ViewLayout' . ucfirst($type);
                    break;
                default:
                    trigger_error("[SyL error] Layout type not found ({$type})", E_USER_ERROR);
                }
                $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
                include_once $classfile;
                $view =& new $classname($dm);
                $view->parseConfig($dm->controller);
            } else {
                if ($type == 'customize') {
                    $classname = $dm->getViewParameter('customizedviewclass');
                    $classfile = $dm->getViewParameter('customizedviewfile');
                    if (!is_file($classfile)) {
                        $classfile1 = SYL_WEBAPP_LIB_DIR . "/{$classfile}";
                        if (!is_file($classfile1)) {
                            trigger_error("[SyL error] Customised View file not found ({$classfile} or {$classfile1})", E_USER_ERROR);
                        }
                        $classfile = $classfile1;
                    }
                } else {
                    $classname = 'SyL_View' . ucfirst($type);
                    $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
                    if (!is_file($classfile)) {
                        trigger_error("[SyL error] Web View file not found ({$classfile})", E_USER_ERROR);
                    }
                }
                include_once $classfile;
                $view =& new $classname($dm);
            }
            break;

        case 'js':
            if (strpos($type, '.') !== false) {
                $classname = 'SyL_View' . implode('', array_map('ucfirst', explode('.', $type)));
                $classfile = SYL_INCLUDE_DIR . "/framework/View/Js/{$classname}.php";
            } else {
                $classname = 'SyL_View' . ucfirst($type);
                $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
            }
            if (!is_file($classfile)) {
                trigger_error("[SyL error] Js View file not found ({$classfile})", E_USER_ERROR);
            }
            include_once $classfile;
            $view =& new $classname($dm);
            break;

        case 'xmlrpc':
            $classname = 'SyL_ViewXmlrpc';
            $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
            include_once $classfile;
            $view =& new $classname($dm);
            break;
        }

        return $view;
    }

    /**
     * XMLեβϽ
     *
     * @access public
     */
    function parseConfig(&$controller)
    {
        $config_file = SYL_APP_DIR . "/{$this->layout_file_name}";
        $reader =& SyL_Config::getObject('layouts', $config_file, $controller);
        $reader->parseXml();
        $this->config += $reader->getConfig();
    }

    /**
     * ƥץ졼ȥǥ쥯ȥ
     * 
     * @access public
     * @return string ƥץ졼ȥǥ쥯ȥ
     */
    function getTemplateDir()
    {
        return $this->dm->getTemplateDir();
    }

    /**
     * ƥץ졼ȥե
     * 
     * @access public
     * @return string ƥץ졼ȥե
     */
    function getTemplateFile()
    {
        if ($this->dm->getViewParameter('viewlayout') === 'true') {
            return $this->config['file'];
        } else {
            return $this->dm->getTemplateFile();
        }
    }

    /**
     * ѥ᡼
     * 
     * @access public
     * @return array ӥ塼Ϥѥ᡼
     */
    function &getActionValues()
    {
        $values = array();

        // 쥤
        if (isset($this->config['templates'])) {
            $values += $this->config['templates'];
        }
        if (isset($this->config['view'])) {
            foreach (array_keys($this->config['view']) as $template) {
                $values[$template] = $this->dm->getTemplateFile();
            }
        }
        if (isset($this->config['parameters'])) {
            $values += $this->config['parameters'];
        }

        // ͤʤ
        $values += $this->dm->getParameters();

        return $values;
    }

    /**
     * ӥ塼ɽ󥯥롼ɥե
     * 
     * @access public
     * @return array ӥ塼ɽ󥯥롼ɥե
     */
    function getIncludeFiles()
    {
        if (isset($this->config['includes']) && is_array($this->config['includes'])) {
            return array_map(create_function('$a', 'return "' . $this->dm->getActionDir() . '/" . $a;'), $this->config['includes']);
        } else {
            return array();
        }
    }

    /**
     * HTML󥰼¹
     * 
     * @access public
     */
    function render()
    {
    }

    /**
     * ɽƤ򥻥å
     * 
     * @access public
     * @param string ɽ
     */
    function setRender(&$render)
    {
        $this->render =& $render;
    }

    /**
     * ɽƤ
     * 
     * @access public
     * @return string HTML
     */
    function &getRender()
    {
        return $this->render;
    }

    /**
     * ƥĥפ򥻥å
     * 
     * @access public
     * @param string ƥĥ
     */
    function setContentType($content_type)
    {
        $this->content_type = $content_type;
    }

    /**
     * ƥĥפ
     * 
     * @access public
     * @return string ƥĥ
     */
    function getContentType()
    {
        return $this->content_type;
    }

    /**
     * ƥ̽Ƚ
     * 
     * @access public
     * @return bool ƥ̽Ƚ
     */
    function isContentLength()
    {
        return (SYL_RESPONSE_LENGTH) ? $this->content_length : false;
    }

    /**
     * gzipȽ
     * 
     * @access public
     * @return bool gzipȽ
     */
    function isGzipCompress()
    {
        return (SYL_RESPONSE_GZIP) ? $this->gzip_compress : false;
    }
}


?>

==> SyL-0.11.0.tar.gz: SyL/include/framework/SyL_View.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_View.php,v 1.19 2007/04/24 16:49:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ̹ǥ饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_View.php,v 1.19 2007/04/24 16:49:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_View
{
    /**
     * ƥĥ
     * 
     * @access protected
     * @var string
     */
    var $content_type = '';
    /**
     * ƥ̽Ƚ
     * 
     * @access protected
     * @var bool
     */
    var $content_length = true;
    /**
     * gzipȽ
     * 
     * @access protected
     * @var bool
     */
    var $gzip_compress = true;
    /**
     * ɽƤΥǡ
     * 
     * @access protected
     * @var string
     */
    var $render = '';
    /**
     * ե졼饹
     * 
     * @access protected
     * @var object
     */
    var $context = null;
    /**
     * ե졼ǡݻ饹
     * 
     * @access protected
     * @var object
     */
    var $data = null;

    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param object ǡ֥
     */
    function SyL_View(&$context, &$data)
    {
        $this->context =& $context;
        $this->data    =& $data;
    }

    /**
     * ƥץ졼ȥ֥Ȥ
     * 
     * @access public
     * @param object ǡ֥
     * @param object ݡͥȥ᥽åɥ֥
     * @return object ӥ塼֥
     */
    function &getObject(&$context, &$data)
    {
        $view      = null;
        $type      = $context->getViewType();
        $classname = '';
        $classfile = '';

        if (!$type || (SYL_ENV_TYPE == 'cmd')) {
            // Nullӥ塼
            $classname = 'SyL_ViewNull';
            $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
        } else if ($type == 'customize') {
            $classname = $context->getCustomizedViewClass();
            $classfile = $context->getCustomizedViewFile();
            if (!is_file($classfile)) {
                $classfile1 = SYL_WEBAPP_LIB_DIR . "/{$classfile}";
                if (!is_file($classfile1)) {
                    trigger_error("[SyL error] Customised View file not found ({$classfile} or {$classfile1})", E_USER_ERROR);
                }
                $classfile = $classfile1;
            }
        } else {
            $classname = 'SyL_View' . implode('', array_map('ucfirst', explode('.', $type)));
            $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
        }

        if (!is_file($classfile)) {
            trigger_error("[SyL error] {$type} View file not found ({$classfile})", E_USER_ERROR);
        }

        include_once $classfile;
        $view =& new $classname($context, $data);

        SyL_Loggers::debug("[View] view info env: " . SYL_ENV_TYPE . " type: {$type} class: {$classname} file: {$classfile}");

        return $view;
    }

    /**
     * ƥץ졼ȥǥ쥯ȥ
     * 
     * @access public
     * @return string ƥץ졼ȥǥ쥯ȥ
     */
    function getTemplateDir()
    {
        return $this->context->getTemplateDir();
    }

    /**
     * ƥץ졼ȥե
     * 
     * @access public
     * @return string ƥץ졼ȥե
     */
    function getTemplateFile()
    {
        return $this->context->getTemplateFile();
    }

    /**
     * ƥĥפ򥻥å
     * 
     * @access public
     * @param string ƥĥ
     */
    function setContentType($content_type)
    {
        $this->content_type = $content_type;
    }

    /**
     * ƥĥפ
     * 
     * @access public
     * @return string ƥĥ
     */
    function getContentType()
    {
        return $this->content_type;
    }

    /**
     * ƥ̽Ƚ
     * 
     * @access public
     * @return bool ƥ̽Ƚ
     */
    function isContentLength()
    {
        return (SYL_RESPONSE_LENGTH) ? $this->content_length : false;
    }

    /**
     * gzipȽ
     * 
     * @access public
     * @return bool gzipȽ
     */
    function isGzipCompress()
    {
        return (SYL_RESPONSE_GZIP) ? $this->gzip_compress : false;
    }

    /**
     * ѥ᡼
     * 
     * @access public
     * @return array ӥ塼Ϥѥ᡼
     */
    function &getActionValues()
    {
        $values  = array();
        $values += $this->context->getParameters();
        $values += $this->data->getsRef();

        return $values;
    }

    /**
     * ɽƤ򥻥å
     * 
     * @access protected
     * @param string ɽ
     */
    function setRender(&$render)
    {
        $this->render =& $render;
    }

    /**
     * ɽƤ
     * 
     * @access public
     * @return string HTML
     */
    function &getRender()
    {
        return $this->render;
    }

    /**
     * HTML󥰼¹
     * 
     * @access public
     */
    function render()
    {
    }
}

?>
